@@ -23,21 +23,24 @@ if (!isGeneric("coordnames<-"))
 if (!isGeneric("dimensions"))
 	setGeneric("dimensions", function(obj)
 		standardGeneric("dimensions"))
-#if (!isGeneric("fullgrid"))
-#	setGeneric("fullgrid", function(obj)
-#		standardGeneric("fullgrid"))
-#if (!isGeneric("fullgrid<-"))
-#	setGeneric("fullgrid<-", function(obj, value)
-#		standardGeneric("fullgrid<-"))
+if (!isGeneric("fullgrid"))
+	setGeneric("fullgrid", function(obj)
+		standardGeneric("fullgrid"))
+if (!isGeneric("fullgrid<-"))
+	setGeneric("fullgrid<-", function(obj, value)
+		standardGeneric("fullgrid<-"))
 if (!isGeneric("geometry"))
 	setGeneric("geometry", function(obj)
 		standardGeneric("geometry"))
-#if (!isGeneric("gridded"))
-#	setGeneric("gridded", function(obj)
-#		standardGeneric("gridded"))
-#if (!isGeneric("is.projected"))
-#	setGeneric("is.projected", function(obj)
-#		standardGeneric("is.projected"))
+if (!isGeneric("gridded"))
+	setGeneric("gridded", function(obj)
+		standardGeneric("gridded"))
+if (!isGeneric("gridded<-"))
+	setGeneric("gridded<-", function(obj, value)
+		standardGeneric("gridded<-"))
+if (!isGeneric("is.projected"))
+	setGeneric("is.projected", function(obj)
+		standardGeneric("is.projected"))
 if (!isGeneric("overlay"))
 	setGeneric("overlay", function(x, y, ...)
 		standardGeneric("overlay"))
@@ -53,12 +56,12 @@ if (!isGeneric("polygons"))
 if (!isGeneric("polygons<-"))
 	setGeneric("polygons<-", function(object, value)
 		standardGeneric("polygons<-"))
-#if (!isGeneric("proj4string"))
-#	setGeneric("proj4string", function(obj)
-#		standardGeneric("proj4string"))
-#if (!isGeneric("proj4string<-"))
-#	setGeneric("proj4string<-", function(obj, value)
-#		standardGeneric("proj4string<-"))
+if (!isGeneric("proj4string"))
+	setGeneric("proj4string", function(obj)
+		standardGeneric("proj4string"))
+if (!isGeneric("proj4string<-"))
+	setGeneric("proj4string<-", function(obj, value)
+		standardGeneric("proj4string<-"))
 if (!isGeneric("spplot"))
 	setGeneric("spplot", function(obj, ...)
 		standardGeneric("spplot"))
